@@ -1,6 +1,7 @@
 import functools
 import inspect
 import logging
+import re
 import shlex
 import threading
 import time
@@ -132,7 +133,7 @@ def log_execution_time(func):
             return await func(*args, **kwargs)
         finally:
             elapsed = time.monotonic() - start_time
-            _logger.info(f'{func.__module__}.{func.__name__} executed in {elapsed:.4f} seconds')
+            _logger.info('%s.%s executed in %.4f seconds', func.__module__, func.__name__, elapsed)
 
     wrapper.__signature__ = inspect.signature(func)
 
@@ -140,4 +141,21 @@ def log_execution_time(func):
 
 
 def to_snake_case(s: str) -> str:
-    return '_'.join(s.strip().lower().split())
+    # Lowercase and strip whitespace
+    s = s.strip().lower()
+
+    # Replace all whitespace with underscores
+    s = re.sub(r'\s+', '_', s)
+
+    # Keep only alphanumeric and underscore characters
+    s = re.sub(r'[^a-z0-9_]', '', s)
+
+    # Collapse consecutive underscores
+    return re.sub(r'_+', '_', s)
+
+
+def parse_string_list(v: str | Sequence[str]) -> Sequence[str]:
+    if isinstance(v, str):
+        return tuple(map(str.strip, v.split(',')))
+
+    return v
